/*

Project:
Prominence effect in health care

E Persson & G Tinghög, et al.

This file by EP w Stata 14.2, 2022-09-02

*/



***** ------------------------ Study 1
import delim using "study_1.csv", clear

***** Describe sample
tab sex
sum age
tab educ
tab experience

***** Check stage 1 stated costs -- what % specifies cost <= cost for the dominated treatment?
* Scenario 1
tabstat pmatch_1 if pmatch_1<1000000, stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_1 if pmatch_1==1000000, stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_1 if pmatch_1>1000000, stat(n) format(%4.0f) /* n=660; included in analysis */
* Scenario 2
tabstat pmatch_2 if pmatch_2<300000, stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_2 if pmatch_2==300000, stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_2 if pmatch_2>300000, stat(n) format(%4.0f) /* n=844; included in analysis */

***** Table 2 -- Main test prominence effect
recode pchoice_1 pchoice_2 (4=0) (5=1) /* to have it as a 0/1 variable */
prtest pchoice_1 = 0.5 if pmatch_1 > 1000000
prtest pchoice_2 = 0.5 if pmatch_2 > 300000

***** Possibly mentioned somewhere -- merge scenarios together
import delim using "study_1.csv", clear
gen ID = _n /* identifier for subject to control for >1 responses per subject */
recode pchoice_1 pchoice_2 (4=0) (5=1)
reshape long pmatch_ pchoice_, i(ID)
* confirm reshape, that we get the same as above in main test -- OK
prtest pchoice_ = 0.5 if pmatch_ > 1000000 & _j==1
prtest pchoice_ = 0.5 if pmatch_ > 300000 & _j==2
* merged results
prtest pchoice_ = 0.5 if (pmatch_ > 1000000 & _j==1) | (pmatch_ > 300000 & _j==2) /* not control for subjects resp two times (both scenarios) */
regr pchoice_ if (pmatch_ > 1000000 & _j==1) | (pmatch_ > 300000 & _j==2), cl(ID) /* control for subjects resp two times (both scenarios) -- this is the one we use */








***** ------------------------ Study 2
import delim using "study_2.csv", clear

***** Sample size & attrition
tab finished_part_1 
tabstat pmatch_1 pmatch_2 pchoice_1 pchoice_2, stat(n)
tab finished_tot
/* 	n=183 took up the survey & consented to participate
	n=148 finished the first part (not in this paper)
	n=131 begun the second part (this paper - promince) (pmatch_1 came first)
	n=126 finished the second part (this paper - prominence) (pchoice_2 came last)
	n=124 finished full survey
*/

*** Describe sample
sum age
tab sex
tab prioexperience
tab prioexperience_clinician /* 14/124 gives % w/ this experience  */
tab prioexperience_researcher /* 71/124 gives % w/ this experience */
tab prioexperience_policymaker /* 25/124 gives % w/ this experience */
tab educ
tab educ_area

***** Check stage 1 stated costs -- what % specifies cost <= cost for the dominated treatment?
* Scenario 1
tabstat pmatch_1 if pmatch_1<100000&pchoice_1!=., stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_1 if pmatch_1==100000&pchoice_1!=., stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_1 if pmatch_1>100000&pchoice_1!=., stat(n) format(%4.0f) /* n=107; included in analysis */
* Scenario 2
tabstat pmatch_2 if pmatch_2<30000&pchoice_2!=., stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_2 if pmatch_2==30000&pchoice_2!=., stat(n) format(%4.0f) /* not included in analysis */
tabstat pmatch_2 if pmatch_2>30000&pchoice_2!=., stat(n) format(%4.0f) /* n=113; included in analysis */

***** Table 3 -- Main test prominence effect
recode pchoice_1 pchoice_2 (4=0) (5=1) /* to have it as a 0/1 variable */
prtest pchoice_1 = 0.5 if pmatch_1 > 100000
prtest pchoice_2 = 0.5 if pmatch_2 > 30000

***** in text -- Main test prominence effect by priority setting experience
recode pchoice_1 pchoice_2 (4=0) (5=1) /* to have it as a 0/1 variable */
prtest pchoice_1 = 0.5 if pmatch_1 > 100000 & prioexperience==1
prtest pchoice_2 = 0.5 if pmatch_2 > 30000 & prioexperience==1

***** in text -- Main test prominence effect Study 1 vs Study 2
prtesti 660 .8984848 107 .8130841 /* manual, exact numbers from main tests above in this file */
prtesti 844 .9443128 113 .8584071 /* manual, exact numbers from main tests above in this file */

***** Possibly mentioned somewhere -- merge scenarios together
import delim using "study_2.csv", clear
gen ID = _n /* identifier for subject to control for >1 responses per subject */
recode pchoice_1 pchoice_2 (4=0) (5=1)
reshape long pmatch_ pchoice_, i(ID)
* confirm reshape, that we get the same as above in main test -- OK
prtest pchoice_ = 0.5 if pmatch_ > 100000 & _j==1
prtest pchoice_ = 0.5 if pmatch_ > 30000 & _j==2
* merged results
prtest pchoice_ = 0.5 if (pmatch_ > 100000 & _j==1) | (pmatch_ > 30000 & _j==2) /* not control for subjects resp two times (both scenarios) */
regr pchoice_ if (pmatch_ > 100000 & _j==1) | (pmatch_ > 30000 & _j==2), cl(ID) /* control for subjects resp two times (both scenarios) -- this is the one we use */








***** ------------------------ Supplementary material



***** Table S1 -- prominence effect for subsamples
import delim using "study_1.csv", clear
recode pchoice_1 pchoice_2 (4=0) (5=1) /* to have it as a 0/1 variable */

* Men vs women
prtest pchoice_1 = 0.5 if pmatch_1 > 1000000 & sex==1 /* Scenario 1 - Men */
prtest pchoice_1 = 0.5 if pmatch_1 > 1000000 & sex==2 /* Scenario 1 - Women */
prtest pchoice_2 = 0.5 if pmatch_2 > 300000 & sex==1 /* Scenario 2 - Men */
prtest pchoice_2 = 0.5 if pmatch_2 > 300000 & sex==2 /* Scenario 2 - Women */

* Experience vs no experience
prtest pchoice_1 = 0.5 if pmatch_1 > 1000000 & experience<3 /* Scenario 1 - Experience */
prtest pchoice_1 = 0.5 if pmatch_1 > 1000000 & experience==3 /* Scenario 1 - No experience */
prtest pchoice_2 = 0.5 if pmatch_2 > 300000 & experience<3 /* Scenario 2 - Exerience */
prtest pchoice_2 = 0.5 if pmatch_2 > 300000 & experience==3 /* Scenario 2 - No experience */



***** Table S2 -- prominence effect by cost estimate -- Study 1

* Scenario 1
import delim using "study_1.csv", clear
keep if pmatch_1 > 1000000
recode pchoice_1 pchoice_2 (4=0) (5=1)
pctile pct = pmatch_1, nq(4) /* create var that contains cut-offs for quartiles */
xtile xct = pmatch_1, cut(pct) /* categorize sbj based on quartile cut-offs */
prtest pchoice_1 = 0.5 if xct==1 /* Table first column */
prtest pchoice_1 = 0.5 if xct==2
prtest pchoice_1 = 0.5 if xct==3
prtest pchoice_1 = 0.5 if xct==4

* Scenario 2
import delim using "study_1.csv", clear
keep if pmatch_2 > 300000
recode pchoice_1 pchoice_2 (4=0) (5=1)
pctile pct = pmatch_2, nq(4) /* create var that contains cut-offs for quartiles */
xtile xct = pmatch_2, cut(pct) /* categorize sbj based on quartile cut-offs */
prtest pchoice_2 = 0.5 if xct==1 /* Table first column */
prtest pchoice_2 = 0.5 if xct==2
prtest pchoice_2 = 0.5 if xct==3
prtest pchoice_2 = 0.5 if xct==4



***** Table S3 -- prominence effect by cost estimate -- Study 2

* Scenario 1
import delim using "study_2.csv", clear
keep if pmatch_1 > 100000
recode pchoice_1 pchoice_2 (4=0) (5=1)
pctile pct = pmatch_1, nq(4) /* create var that contains cut-offs for quartiles */
xtile xct = pmatch_1, cut(pct) /* categorize sbj based on quartile cut-offs */
prtest pchoice_1 = 0.5 if xct==1 /* Table S3 first column */
prtest pchoice_1 = 0.5 if xct==2
prtest pchoice_1 = 0.5 if xct==3
prtest pchoice_1 = 0.5 if xct==4

* Scenario 2
import delim using "study_2.csv", clear
keep if pmatch_2 > 30000
recode pchoice_1 pchoice_2 (4=0) (5=1)
pctile pct = pmatch_2, nq(4) /* create var that contains cut-offs for quartiles */
xtile xct = pmatch_2, cut(pct) /* categorize sbj based on quartile cut-offs */
prtest pchoice_2 = 0.5 if xct==1 /* Table S3 second column */
prtest pchoice_2 = 0.5 if xct==2
prtest pchoice_2 = 0.5 if xct==3
prtest pchoice_2 = 0.5 if xct==4


